#!/bin/bash
# Copyright (c) 2014 Mellanox Technologies. All rights reserved.
#
# This Software is licensed under one of the following licenses:
#
# 1) under the terms of the "Common Public License 1.0" a copy of which is
#    available from the Open Source Initiative, see
#    http://www.opensource.org/licenses/cpl.php.
#
# 2) under the terms of the "The BSD License" a copy of which is
#    available from the Open Source Initiative, see
#    http://www.opensource.org/licenses/bsd-license.php.
#
# 3) under the terms of the "GNU General Public License (GPL) Version 2" a
#    copy of which is available from the Open Source Initiative, see
#    http://www.opensource.org/licenses/gpl-license.php.
#
# Licensee has the right to choose one of the above licenses.
#
# Redistributions of source code must retain the above copyright
# notice and one of the license notices.
#
# Redistributions in binary form must reproduce both the above copyright
# notice, one of the license notices in the documentation
# and/or other materials provided with the distribution.
readonly SUCCESS=0
readonly FAILURE=1
readonly OFED_DIR="/opt/ofed/MLNX_OFED_light"
readonly OFED_INSTALL_SCRIPT="${OFED_DIR}/mlnxofedinstall"
readonly OFED_INSTALL_SCRIPT_CMD="/usr/bin/perl ${OFED_DIR}/mlnxofedinstall"
readonly SCRIPT_NAME=`basename $0`

# This functions print logs to /var/log/messages
function logger_print () {
    priority=$1
    msg=$2
    echo "${SCRIPT_NAME}: $priority - $msg"
    logger -t $SCRIPT_NAME "$priority: $msg"
}

if [ ! -x $OFED_INSTALL_SCRIPT ] ; then
    logger_print err "Failed to find $OFED_INSTALL_SCRIPT"
    exit ${FAILURE}
fi

${OFED_INSTALL_SCRIPT_CMD} -q --without-fw-update
if [ $? -ne ${SUCCESS} ] ;then
    logger_print err "Failed execute ${OFED_INSTALL_SCRIPT_CMD} error code $?"
    exit ${FAILURE}
fi

BUS_ID=`lspci | grep -m 1 Mellanox | cut -d' ' -f1`
if [ -z $BUS_ID ]; then
    logger_print info "Not found Bus, skipping firmware upgrade"
    exit ${SUCCESS}
fi

logger_print info "BUS ID = ${BUS_ID}"
mstflint -d ${BUS_ID} q | grep -i PSID | grep MT_
if [ $? -ne ${SUCCESS} ] ;then
    logger_print info "Not Mellanox Card, skipping firmware upgrade"
    exit ${SUCCESS}
fi

${OFED_INSTALL_SCRIPT_CMD} -q --enable-sriov
if [ $? -ne ${SUCCESS} ] ;then
    logger_print err "Failed enable sriov ${OFED_INSTALL_SCRIPT_CMD} error code $?"
    exit ${FAILURE}
fi

exit ${SUCCESS}